@@ -35,19 +35,35 @@
 #' @importFrom rlang enquo :=
 #' @importFrom dplyr select left_join mutate_if
 #' @importFrom tibble data_frame
+#' @importFrom raster stack crosstab reclassify
+#' @importFrom tidyr spread
 #'
 #' @examples
 #' library(sf)
 #' data("regions1")
 #' data("regions2")
-#' vm = vmeasure_calc(regions1, z, regions2, z)
+#' vm = vmeasure_calc(x = regions1, y = regions2, x_name = z, y_name = z)
 #' vm
 #'
 #' plot(vm$map1["rih"])
 #' plot(vm$map2["rih"])
 #'
+#' @aliases vmeasure_calc
+#' @rdname vmeasure_calc
+#'
 #' @export
-vmeasure_calc = function(x, x_name, y, y_name, B = 1, precision = NULL){
+vmeasure_calc <- function(x,
+                          y,
+                          x_name,
+                          y_name,
+                          B = 1,
+                          precision = NULL){
+  UseMethod("vmeasure_calc")
+}
+
+#' @name vmeasure_calc
+#' @export
+vmeasure_calc.sf = function(x, y, x_name, y_name, B = 1, precision = NULL){
 
   stopifnot(inherits(st_geometry(x), "sfc_POLYGON") || inherits(st_geometry(x), "sfc_MULTIPOLYGON"))
   stopifnot(inherits(st_geometry(y), "sfc_POLYGON") || inherits(st_geometry(y), "sfc_MULTIPOLYGON"))
@@ -116,13 +132,54 @@ vmeasure_calc = function(x, x_name, y, y_name, B = 1, precision = NULL){
   return(sabre_result)
 }
 
+#' @name vmeasure_calc
+#' @export
+vmeasure_calc.RasterLayer = function(x, y, x_name = NULL, y_name = NULL, B = 1, precision = NULL){
+
+  stopifnot(inherits(x, "RasterLayer"))
+  stopifnot(inherits(y, "RasterLayer"))
+  z = stack(x, y)
+
+  z_df = t(crosstab(z))
+  # z_df = na.omit(z_df)
+  # z_df = spread(z_df, "layer.1", "Freq")
+  # rownames(z_df) = z_df$layer.2
+  # z_df = z_df[-1]
+
+  SjZ = apply(z_df, 2, entropy.empirical, unit = "log2")
+  SjR = apply(z_df, 1, entropy.empirical, unit = "log2")
+
+  SZ = entropy.empirical(rowSums(z_df), unit = "log2")
+  SR = entropy.empirical(colSums(z_df), unit = "log2")
+
+  x_df = data.frame(map1 = as.numeric(colnames(z_df)),
+                    rih = SjZ/SZ,
+                    row.names = NULL, stringsAsFactors = FALSE) # map1
+  y_df = data.frame(map2 = as.numeric(rownames(z_df)),
+                    rih = SjR/SR,
+                    row.names = NULL, stringsAsFactors = FALSE) # map2
+
+  x2 = stack(x, reclassify(x, x_df))
+  y2 = stack(y, reclassify(y, y_df))
+  names(x2) = c("map1", "rih")
+  names(y2) = c("map2", "rih")
+
+  v_result = vmeasure(x = colSums(z_df), y = rowSums(z_df), z = z_df, B = B)
+  # sabre_result = list(x, y, v_result)
+  sabre_result = list(map1 = x2, map2 = y2, v_measure = v_result$v_measure,
+                      homogeneity = v_result$homogeneity,
+                      completeness = v_result$completeness)
+  class(sabre_result) = c("vmeasure_vector")
+  return(sabre_result)
+}
+
 #' @export
 format.vmeasure_vector = function(x, ...){
   paste("The SABRE results:\n\n",
         "V-measure:", round(x$v_measure, 2), "\n",
         "Homogeneity:", round(x$homogeneity, 2), "\n",
         "Completeness:", round(x$completeness, 2), "\n\n",
-        "The spatial objects could be retrived with:\n",
+        "The spatial objects can be retrieved with:\n",
         "$map1", "- the first map\n",
         "$map2", "- the second map")
 }
