@@ -2,8 +2,8 @@ context("test-eco-us.R")
 data("regions1")
 data("regions2")
 
-vm = vmeasure_calc(regions1, z, regions2, z)
-mc = mapcurves_calc(regions1, z, regions2, z)
+vm = vmeasure_calc(x = regions1, y = regions2, x_name = z, y_name = z)
+mc = mapcurves_calc(x = regions1, y = regions2, x_name = z, y_name = z)
 
 test_that("sabre works on vector", {
   expect_equal(c(vm[[3]], vm[[4]], vm[[5]]), c(0.36, 0.32, 0.42), tolerance = 0.01)
